@@ -293,8 +293,11 @@ class Exploit < Msf::Module
       unless has_auto_target?(info['Targets'])
         # Don't add the automatic target unless there's already more than one target to pick from
         if info['Targets'].count > 1
-          auto = ["Automatic", { 'AutoGenerated' => true}]
-          info['Targets'].unshift(auto)
+          # Finally, only add the target if there is a remote host option
+          if self.respond_to?(:rhost)
+            auto = ["Automatic", { 'AutoGenerated' => true}]
+            info['Targets'].unshift(auto)
+          end
         end
       end
     end
